Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Incoming ¶
type Incoming struct {
// contains filtered or unexported fields
}
func New ¶
func New() *Incoming
New creates a new instance of the Incoming struct. Just a simple constructor.
func (*Incoming) Add ¶
Add adds a new check case to the Incoming object. It takes in a key(string), value(any type), and typ(Type). It returns the Incoming struct itself.
type Type ¶
type Type int
const ( None Type = iota // unknown for a checking type Inter // any / interface{} Any // any / interface{} Int32 // simple integer 32 Int32N // simple non-negative integer 32 Int32P // simple positive integer 32 ListInt32N // list of simple non-negative integer 32 ListInt32P // list of simple positive integer 32 Int64 // simple integer 64 Int64N // simple non-negative integer 64 Int64P // simple positive integer 64 Float32 // simple float 32 Float32N // simple non-negative float 32 Float32P // simple positive float 32 Float64 // simple float 64 Float64N // simple non-negative float 64 Float64P // simple positive float 64 String // simple string StringP // non-empty string // ListString - list has length > 0 ListString // non-empty list of any values // ListStringP - list has at least one non-empty value ListStringP // non-empty list containing at least one non-empty value // ListStringS - all values in list are not empty ListStringS // non-empty list with all non-empty values )
Click to show internal directories.
Click to hide internal directories.